@@ -163,6 +163,9 @@ class Data:
     # kernel uid get by uuid root device
     cl_kernel_uid = {'hide':True}
 
+    # supported languages
+    os_lang = {}
+
     # this variable work with template function belong(package_name)
     # if the variable is defined then will use only template, which 
     # has package_name in belong equal value of this variable or
